@@ -325,6 +325,8 @@ function show(io::IO, a::ZZRing)
   end
 end
 
+
+
 ###############################################################################
 #
 #   Canonicalisation
@@ -1550,12 +1552,15 @@ function is_squarefree(n::Union{Int, ZZRingElem})
   if e > 1
     return false
   end
-  return isone(maximum(values(factor(n).fac); init = 1))
+  return isone(maximum(y for (_,y) in factor(n); init = 1))
 end
 
 is_divisible_by_four(n::Integer) = (n % 4) == 0
 is_divisible_by_four(n::ZZRingElem) = ((n % UInt) % 4) == 0
 
+pretty_lt(x::ZZRingElem, y::ZZRingElem) = isless(x, y)
+pretty_eq(x::ZZRingElem, y::ZZRingElem) = (x == y)
+
 ################################################################################
 #
 #   Factor trial range
@@ -3050,7 +3055,7 @@ function _rational_reconstruction(a::ZZRingElem, b::ZZRingElem; error_tolerant::
   if unbalanced
     n = ZZ()
     d = ZZ()
-    fl = ratcec!(n, d, a, b)
+    fl = _ratrec!(n, d, a, b)
     return fl, n, d
   elseif error_tolerant
     m = matrix(ZZ, 2, 2, [a, ZZRingElem(1), b, ZZRingElem(0)])
